==> cetus-5.3.5.tgz: package/search/index.js <==
"use strict";

let Promise = require('bluebird'),
    _ = require('underscore'),
    AWS = require('aws-sdk'),
    csd = {},
    utilities = require('../utilities/index'),
    config = {},
    models = require ('mongoose').models,
    paramReplace = {
        param1: (str, data) => str.replace (/param1/g, data),
        param2: (str, data) => str.replace (/param2/g, data),
        param3: (str, data) => str.replace (/param3/g, data),
        param4: (str, data) => str.replace (/param4/g, data),
        param5: (str, data) => str.replace (/param5/g, data),
    },
    services = {};


//// Public --------------------------------------------------------------------------------------

module.exports.init = function (options)  {
    if (options && _.isObject(options)) _.extend(config, options);

    _.each (config.domains, function (domain, domainName) {
        if (domain.enabled) {

            csd['doc-' + domainName] = new AWS.CloudSearchDomain ( _.extend(
                _.pick (domain, "apiVersion", "region", "sslEnabled"),
                { endpoint: domain.docEndpoint },
                config.options
            ));

            csd['search-' + domainName] = new AWS.CloudSearchDomain ( _.extend(
                _.pick (domain, "apiVersion", "region", "sslEnabled"),
                { endpoint: domain.searchEndpoint },
                config.options
            ));
        }
    });
};

module.exports.uploadDocuments = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search uploadDocuments');

    return new Promise ( (resolve, reject) => {

        if (!data.documents.length) return reject (new utilities.error.aws (823));

        let domainSettings = config.domains["shufl-items"],
            documents = JSON.stringify (domainSettings.itemAddFormat (data.documents) ),
            params = {
                contentType:    domainSettings.contentType,
                documents:      documents
            };

        if (documents === "[]") return resolve(null);

        csd['doc-shufl-items'].uploadDocuments(params).promise()
            .then(resolve)
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                return reject (err);
            });
    });
};

/*module.exports.uploadExperiences = function (data, callback) { //data = {documents: Araay of documents}
    utilities.logger.info('framework/search uploadExperiences');

    return new Promise (function (resolve, reject) {

        if (!data.documents.length) reject(new utilities.error.aws (823));

        let domainSettings = config.domains["shufl-exps"],
            documents = JSON.stringify ( domainSettings.formatAddExp (data.documents) )
            params = {
                contentType:    domainSettings.contentType,
                documents:      documents
            };

        csd['doc-shufl-exps'].uploadDocuments(params).promise()
            .then(resolve)
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });

};*/

module.exports.removeDocuments = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search removeDocuments');

    return new Promise (function (resolve, reject) {
        let domainSettings = config.domains[data.domainName],
            params = {
                contentType:    domainSettings.contentType,
                documents:      JSON.stringify ( domainSettings.itemRemFormat (data.documents) )
            };

        csd['doc-shufl-items'].uploadDocuments(params).promise()
            .then ( resolve )
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });
};

/*module.exports.removeExperiences = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search removeExperiences');

    return new Promise (function (resolve, reject) {
        let domainSettings = config.domains[data.domainName],
            params = {
                contentType:    domainSettings.contentType,
                documents:      JSON.stringify ( domainSettings.formatRemExp (data.documents) )
            };

        csd['doc-shufl-exps'].uploadDocuments(params).promise()
            .then ( resolve )
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });
};*/

module.exports.search = function (data) { // data = {domainName: String, query: query String}
    utilities.logger.info('framework/search search');

    return new Promise ( (resolve, reject) => {

        let domainSettings = config.domains[data.domainName],
            params = {
                query:          domainSettings.queryFormat ? domainSettings.queryFormat(data) : "",
                queryParser:    'structured',
                size:           data.limit,
            };

        if ( _.has (data, 'skip') ) params.start = data.skip;
        else if (_.has (data, 'cursor')) params.cursor = data.cursor;

        if ( _.has (data, 'distanceKM') ) {
            params.filterQuery = domainSettings.formatFilter (data);
        } /*else if ( _.has (data, 'coords') ) {
            let expr = domainSettings.exprFormat ? domainSettings.exprFormat(data) : "";
            if (expr.length) params.expr = expr;
        }*/

        if (_.has (data, 'searchSort')) {
            if (_.has (data, 'coords') && data.searchSort.coords) {
                let expr = domainSettings.exprFormat ? domainSettings.exprFormat(data) : "";
                if (expr.length) params.expr = expr;
            }
            let sort = domainSettings.sortFormat ? domainSettings.sortFormat(data) : "";
            if (sort.length) params.sort = sort;
        }

        if (_.has (data, 'withCounts')) {
            let facet = domainSettings.formatFacet ? domainSettings.formatFacet(data) : "";
            if (facet.length) params.facet = facet;
        }

        utilities.logger.info(' ---- Search Parameters ---- ');
        utilities.logger.info(params);
        utilities.logger.info(' ---- ----------------- ---- ');

        return csd['search-' + data.domainName].search(params).promise()
            .then( results => {
                if (results.hits.found > 0) return resolve ({ items: _.pluck (results.hits.hit, 'fields'), count: results.hits.found, cursor: results.hits.cursor, facets: results.facets });
                else return resolve ({items: [], count: 0, cursor: null});
            })
            .catch(e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });

};

==> cetus-8.0.30.tgz: package/search/index.js <==
"use strict";

let Promise = require('bluebird'),
    _ = require('underscore'),
    AWS = require('aws-sdk'),
    csd = {},
    utilities = require('../utilities/index'),
    config = {},
    models = require ('mongoose').models,
    paramReplace = {
        param1: (str, data) => str.replace (/param1/g, data),
        param2: (str, data) => str.replace (/param2/g, data),
        param3: (str, data) => str.replace (/param3/g, data),
        param4: (str, data) => str.replace (/param4/g, data),
        param5: (str, data) => str.replace (/param5/g, data),
    },
    services = {};


//// Public --------------------------------------------------------------------------------------

module.exports.init = function (options)  {
    if (options && _.isObject(options)) _.extend(config, options);

    _.each (config.domains, function (domain, domainName) {
        if (domain.enabled) {

            csd['doc-' + domainName] = new AWS.CloudSearchDomain ( _.extend(
                _.pick (domain, "apiVersion", "region", "sslEnabled"),
                { endpoint: domain.docEndpoint },
                config.options
            ));

            csd['search-' + domainName] = new AWS.CloudSearchDomain ( _.extend(
                _.pick (domain, "apiVersion", "region", "sslEnabled"),
                { endpoint: domain.searchEndpoint },
                config.options
            ));
        }
    });
};

module.exports.uploadDocuments = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search uploadDocuments');

    if (!data.documents.length) return Promise.resolve (new utilities.error.aws (823));

    let domainSettings = config.domains["shufl-items"],
        documents = JSON.stringify (domainSettings.itemAddFormat (data.documents) ),
        params = {
            contentType:    domainSettings.contentType,
            documents:      documents
        };

    if (documents === "[]") return Promise.resolve(null);

    return csd['doc-shufl-items'].uploadDocuments(params).promise()
        .then(results => results)
        .catch(e => e);
};

/*module.exports.uploadExperiences = function (data, callback) { //data = {documents: Araay of documents}
    utilities.logger.info('framework/search uploadExperiences');

    return new Promise (function (resolve, reject) {

        if (!data.documents.length) reject(new utilities.error.aws (823));

        let domainSettings = config.domains["shufl-exps"],
            documents = JSON.stringify ( domainSettings.formatAddExp (data.documents) )
            params = {
                contentType:    domainSettings.contentType,
                documents:      documents
            };

        csd['doc-shufl-exps'].uploadDocuments(params).promise()
            .then(resolve)
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });

};*/

module.exports.removeDocuments = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search removeDocuments');

    let domainSettings = config.domains[data.domainName],
        params = {
            contentType:    domainSettings.contentType,
            documents:      JSON.stringify ( domainSettings.itemRemFormat (data.documents) )
        };

    return csd['doc-shufl-items'].uploadDocuments(params).promise()
        .then (results => results )
        .catch(e => e);
};

/*module.exports.removeExperiences = function (data) { //data = {domainName: String, documents: Araay of documents}
    utilities.logger.info('framework/search removeExperiences');

    return new Promise (function (resolve, reject) {
        let domainSettings = config.domains[data.domainName],
            params = {
                contentType:    domainSettings.contentType,
                documents:      JSON.stringify ( domainSettings.formatRemExp (data.documents) )
            };

        csd['doc-shufl-exps'].uploadDocuments(params).promise()
            .then ( resolve )
            .catch( e => {
                let err = new utilities.error.aws (e.code);
                utilities.logger.error(err);
                utilities.logger.error(e);
                reject (err);
            });
    });
};*/

module.exports.search = function (data) { // data = {domainName: String, query: query String}
    utilities.logger.info('framework/search search');

    let domainSettings = config.domains[data.domainName],
        params = {
            query:          domainSettings.queryFormat ? domainSettings.queryFormat(data) : "",
            queryParser:    'structured',
            size:           data.limit,
        };

    if ( _.has (data, 'skip') ) params.start = data.skip;
    else if (_.has (data, 'cursor')) params.cursor = data.cursor;

    if ( _.has (data, 'distanceKM') ) {
        params.filterQuery = domainSettings.formatFilter (data);
    } /*else if ( _.has (data, 'coords') ) {
        let expr = domainSettings.exprFormat ? domainSettings.exprFormat(data) : "";
        if (expr.length) params.expr = expr;
    }*/

    if (_.has (data, 'searchSort')) {
        if (_.has (data, 'coords') && data.searchSort.coords) {
            let expr = domainSettings.exprFormat ? domainSettings.exprFormat(data) : "";
            if (expr.length) params.expr = expr;
        }
        let sort = domainSettings.sortFormat ? domainSettings.sortFormat(data) : "";
        if (sort.length) params.sort = sort;
    }

    if (_.has (data, 'withCounts')) {
        let facet = domainSettings.formatFacet ? domainSettings.formatFacet(data) : "";
        if (facet.length) params.facet = facet;
    }

    utilities.logger.info(' ---- Search Parameters ---- ');
    utilities.logger.info(params);
    utilities.logger.info(' ---- ----------------- ---- ');

    return csd['search-' + data.domainName].search(params).promise()
        .then( results => {
            if (results.hits.found > 0) return {items: _.pluck (results.hits.hit, 'fields'), count: results.hits.found, cursor: results.hits.cursor, facets: results.facets};
            else return {items: [], count: 0, cursor: null};
        })
        .catch(e => e);
};
